AnimatedIconController class
Controller for programmatic control of AnimatedSVGIcon animations.
Use this controller when you need to trigger animations externally, for example when using icons inside IconButton or custom widgets.
Example:
final controller = AnimatedIconController();
IconButton(
onPressed: () {
controller.animate();
// your action here
},
icon: AppleIcon(
controller: controller,
interactive: false, // disable internal gesture handling
),
)
- Inheritance
-
- Object
- ChangeNotifier
- AnimatedIconController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animate(
) → void - Triggers the animation to play forward.
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
) → void - Resets the animation to its initial state.
-
stop(
) → void - Stops the current animation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited